% Contour plot, uv-plot, of the co-polar far-field function. 
%
% Complement to Figure 2.11 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg and Madeleine Kildal Schilliger.

% Define inputs.
u = -5:0.01:5;
v = -5:0.01:5;
[uu, vv] = ndgrid(u, v);
w = pi/2;
min_dB = -50;

% Calculate.
t = linspace(-1, 1, 401);
dt = t(2) - t(1);
GH = zeros(size(u));
for ii = 1:numel(u)
    GH(ii) = dt * trapz(cos(0.5*pi*t).*exp(1j*(-w*t.^2+pi*u(ii)*t)));
end
GH = GH/max(abs(GH));
GE = zeros(size(v));
for ii = 1:numel(v)
    GE(ii) = dt * trapz(exp(1j*(-w*t.^2+pi*v(ii)*t)));
end
GE = GE/max(abs(GE));
G = GH.' * GE;
G_dB = max(20*log10(abs(G)), min_dB);

% Plot a surf plot.
figure;
G_dB(end,end) = -100;  % hack to avoid graphic glitch when saving plot
surf(uu, vv, G_dB);
colormap(jet(-min_dB/2.5));
shading flat;
fs = 9;
%xlabel('$\textsf{u = $\theta$ cos($\varphi$) ( $^{\circ}$)}$', 'Interpreter', 'latex', 'FontSize', fs);
%ylabel('$\textsf{v = $\theta$ sin($\varphi$) ( $^{\circ}$)}$', 'Interpreter', 'latex', 'FontSize', fs);
xlabel('u = \theta cos(\phi) ( \circ)', 'Interpreter', 'tex');
ylabel('v = \theta sin(\phi) ( \circ)', 'Interpreter', 'tex');
view(0, 90);
caxis([min_dB 0]);
colorbar;
axis image;
set(gca, 'TickDir', 'out');
set(gca, 'XTickMode', 'manual');
set(gca, 'XTick', -5:5);
grid off;
box on;
if exist('savefigs', 'var') && savefigs
    save_fig('Fig2-11.eps', 14, 10, 500);
    save_fig('Fig2-11.png', 14, 10, 600);
    colormap(flipud(gray(-min_dB/5)));
    save_fig('Fig2-11gray.eps', 14, 10, 500);
    save_fig('Fig2-11gray.png', 14, 10, 600);
end