% Efficiency reduction due to sidelobe.
%
% Complement to Figure 2.16 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define inputs.
parameter_deg = [5 10 20 40 80 160];
sidelobe_envelope_dBi = -15:0.1:15;

% Calculate directivity reduction due to sidelobe.
parameter_rad = parameter_deg*pi/180;
abs_A_squared = 10.^((sidelobe_envelope_dBi-3)/10);
e_sidelobe_reduction = (1 + 0.5 * abs_A_squared' * parameter_rad) .^ -1;

% Plot.
figure;
plot(sidelobe_envelope_dBi, 10*log10(e_sidelobe_reduction));
axis([-15 15 -3 0]);
grid on;
xlabel('Sidelope envelope [dBi]');
ylabel('Directivity reduction [dB]');
lgnds = cell(size(parameter_deg));
for ii = 1:numel(lgnds)
    lgnds{ii} = sprintf('sin(\\theta_m)\\Delta\\theta = %.0f deg', ...
        parameter_deg(ii));
end
legend(lgnds, 'Location', 'southwest');
