% Fading signal and its cumulative distribution function.
%
% Complement to Figure 3.1 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Defined input.
N = 30e3;      % number of samples
N_plot = 500;  % number of samples to use in for first plot

% Reset random generator to be able to reproduce plots exactly.
reset(RandStream.getGlobalStream, 123);

% Generate normalized complex Gaussian samples and variables for plots.
t = linspace(0, 1, N_plot);
y = complex(randn(N,1), randn(N,1));
y = y / sqrt(mean(abs(y).^2));  % average power = 1
y_dB = 20*log10(abs(y));
y_dB_sorted = sort(y_dB);
cdf = (1:N)' / N;

% Generate theoretical Rayleigh distribution.
y_theory_dB = -30:10;
y_theory = 10.^(y_theory_dB/20);
cdf_theory = 1 - exp(-y_theory.^2);

% Plot signal.
figure;
plot(t, y_dB(1:N_plot), 'k-');
grid on;
xlabel('Time (s)');
ylabel('Normalized signal amplitude (dB)');
ylim([-30 10]);
if exist('savefigs', 'var') && savefigs
    save_fig('fig_03_01a.eps', 7*1.5, 6*1.5);
end

% Plot CDF:s.
semilogy(y_theory_dB, cdf_theory, 'r-', 'LineWidth', 0.5); hold on;
semilogy(y_dB_sorted, cdf, 'k--', 'LineWidth', 1);
xlim([-30 10]);
ylim([1e-3 1e0]);
grid on;
tmp = sprintf(' %g%%',100*get(gca,'YTick'));
set(gca, 'YTickLabel', strsplit(tmp(2:end)));
xlabel('Normalized power level (dB)');
ylabel('Cumulative probability (-)');
legend('Theoretical Rayleigh distribution', ...
    'Simulated Rayleigh distribution', 'Location', 'southeast');
if exist('savefigs', 'var') && savefigs
    save_fig('fig_03_01b.eps', 7*1.5, 6*1.5);
end
