% Scatter plot of complex samples.
%
% Complement to Figure 3.14 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Defined input.
N = 500;  % number of samples

% Reset random generator to be able to reproduce plots exactly.
reset(RandStream.getGlobalStream, 123);

% Generate normalized complex Gaussian samples and variables for plots.
y = complex(randn(N,1), randn(N,1));
y = y * sqrt(0.02/mean(abs(y).^2));
deterministic_part = 0.5 + 0.6j;
y = y + deterministic_part;

% Scatter plot.
figure;
plot(real(y), imag(y), 'k.');
hold on;
plot([0 real(deterministic_part)], [0 imag(deterministic_part)], 'r-', ...
    'LineWidth', 2);
text(0.15, 0.1, 'Deterministic part', 'Color', 'r');
axis image;
axis([-1 1 -1 1]);
grid on;
xlabel('Real part');
ylabel('Imaginary part');
if exist('savefigs', 'var') && savefigs
    save_fig('Fig3-14b.eps', 7*1.13, 6*1.13);
end
