% CDF of received voltage; linearly polarized antenna and two orthogonally
% polarized antenna ports.
%
% Complement to Figure 3.22 in Foundations of Antennas by Per-Simon Kildal.

% By Madeleine Kildal Schilliger.

% Start values:
N = 1000;
phi_deg = (90)*rand(1,N);
phi = phi_deg *pi/180;

% One linearly polarized receive port.
h_11 = sort(cos(phi));
CDF = 1-acos(abs(h_11))/(pi/2);
h_11_dB = 20*log10(h_11);

% MRC: Two ortognoally polarized receive ports.
h_MRC = 1;
h_MRC = h_MRC * ones(1, N);
h_MRC_dB = 20*log10(h_MRC);

% Plot:
figure();
semilogy(h_11_dB, CDF, 'k')
hold on
semilogy(h_MRC_dB, CDF, 'b--')

axis([-20 5 0.01 1])
grid on
xlabel('Received level (dB)')
ylabel('CDF')
legend('1x1', '2x1 MRC', 'Location','SouthWest')

if exist('savefigs', 'var') && savefigs
    save_fig('Fig3-22.eps', 10*1.3, 7.5*1.3);
end