% Radiation patterns of a halfwave dipole.
%
% Complement to Figure 5.4b in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg and modified by Madeleine Kildal Schilliger.

% Define theta and phi angles.
theta_deg = 0:180;
phi_deg = -180:180;
[theta, phi] = ndgrid(theta_deg*pi/180, phi_deg*pi/180);

% Far-field function (normalized) of a y-directed halfwave dipole
% Calculate Eq. (5.12). Fix division with zero problems.
ss = sin(theta).*sin(phi);
jj = cos(0.5*pi*ss) ./ (1-ss.^2);
indx = abs(1-ss.^2) < 1e-8;
jj(indx) = pi/4;  % from Taylor expansion

% Far-field function (normalized) of a y-directed halfwave dipole from 
% Eq. (5.11).
G_d_theta = jj .* cos(theta) .* sin(phi);
G_d_phi = jj .* cos(phi);

%% 3D radiation pattern
% Plot total 3D radiation pattern 
G_d_tot = sqrt(abs(G_d_theta).^2+abs(G_d_phi).^2); %Equation 2.45
G_d_tot_dB = 20*log10(G_d_tot);
range_dB = 30;
G_d_tot_dB_scaled = max(G_d_tot_dB+range_dB,0) / range_dB;

figure;
zoomfactor = 0.5;
plot_3d_farfield_sub(theta, phi, G_d_tot_dB_scaled)
zoom(zoomfactor)
if exist('savefigs', 'var') && savefigs
    save_fig('Fig5-04b.eps', 14, 10, 450)
    colormap(flipud(pink(30)));
    save_fig('Fig5-04bgray.eps', 14, 10, 450);
end

