% Impedance calculations for dipoles.
%
% Complement to Figure 5.9 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Plot (a):

% Define parameters.
Lmin = 0.3;
Lmax = 0.6;
a = [0.005 0.01 0.02 0.05];
t = 0.005;
Zref = 50;
pstyle = {'b-', 'r-', 'g-', 'k-'};

% Calculate and plot for different dipole thicknesses.
figure;
lbls = cell(numel(a), 1);
for ii = 1:numel(a)
    [Ldip, Zdip] = impedance_dipole_thinwire(Lmin, Lmax, t, a(ii));
    S11 = (Zdip-Zref) ./ (Zdip+Zref);
    lbls{ii} = sprintf('a = %.3f \\lambda', a(ii));
    plot(Ldip, 20*log10(abs(S11)), pstyle{ii});
    hold on;
end
xlabel('Dipole length [\lambda]');
ylabel('Reflection coefficient [dB]');
axis([Lmin Lmax -30 0]);
grid on;
legend(lbls, 'Location', 'southeast');

% Plot (b) and (c):

% Define parameters.
Lmin = 0.2;
Lmax = 0.6;
a_thick = 0.05;
a_thin = 0.005;
t = 0.005;

% Calculate for different dipole thicknesses (thin wires).
[~   , Zdip_thick] = impedance_dipole_thinwire(Lmin, Lmax, t, a_thick);
[Ldip, Zdip_thin ] = impedance_dipole_thinwire(Lmin, Lmax, t, a_thin );

% Calculate for microstrip dipole.
t_micros = 0.0025;
w_micros = 0.005;
[Ldip_micros, Zdip_micros] = impedance_dipole_microstrip(Lmin, Lmax, ...
    t_micros, w_micros);

% Plot impedance.
figure;
subplot(1,2,1);
plot(Ldip       , real(Zdip_thick ), 'k-'); hold on;
plot(Ldip       , imag(Zdip_thick ), 'b-');
plot(Ldip       , imag(Zdip_thin  ), 'r-');
plot(Ldip_micros, imag(Zdip_micros), 'g-');
plot(Ldip       , real(Zdip_thin  ), 'k-');
plot(Ldip_micros, real(Zdip_micros), 'k-');
xlabel('Dipole length [\lambda]');
ylabel('R and X [ohm]');
axis([Lmin Lmax -100 100]);
grid on;
legend('R, all cases', ...
    sprintf('X, a = %.3f \\lambda thick', a_thick), ...
    sprintf('X, a = %.3f \\lambda thin' , a_thin), ...
    sprintf('X, w = %.3f \\lambda strip', w_micros), 'Location', 'southwest');

% Plot admittance.
subplot(1,2,2);
plot(Ldip       , real(50./Zdip_thick ), 'b-' ); hold on;
plot(Ldip       , real(50./Zdip_thin  ), 'r-' );
plot(Ldip_micros, real(50./Zdip_micros), 'g-' );
plot(Ldip       , imag(50./Zdip_thick ), 'b--');
plot(Ldip       , imag(50./Zdip_thin  ), 'r--');
plot(Ldip_micros, imag(50./Zdip_micros), 'g--');
xlabel('Dipole length [\lambda]');
ylabel('50*G and 50*B [S]');
axis([0.35 0.55 -0.5 1]);
grid on;
legend(sprintf('50*G, a = %.3f \\lambda thick', a_thick ), ...
       sprintf('50*G, a = %.3f \\lambda thin' , a_thin  ), ...
       sprintf('50*G, w = %.3f \\lambda strip', w_micros), ...
       sprintf('50*B, a = %.3f \\lambda thick', a_thick ), ...
       sprintf('50*B, a = %.3f \\lambda thin' , a_thin  ), ...
       sprintf('50*B, w = %.3f \\lambda strip', w_micros), 'Location', 'southwest');
