% Radiation patterns of a halfwave dipole.
%
% Complement to Figure 5.12c in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define theta and phi angles.
theta_deg = 0:180;
phi_deg = -180:180;
[theta, phi] = ndgrid(theta_deg*pi/180, phi_deg*pi/180);
range_dB = 30;

% Far-field function (normalized) of a y-directed incremental electric current from
% Far-field function from Eq. (5.56).
h_lambda = [0.125, 0.375, 1]; %Height in lambda
kh = 2*pi*h_lambda;
G_vid_theta = cell(numel(kh),1);
G_vid_phi = cell(numel(kh),1);
G_vid_tot_dB_scaled = cell(numel(kh),1);

for ii = 1:numel(kh);    
    G_vid_theta{ii} = sin(theta) .* cos(kh(ii)*cos(theta));
    G_vid_theta{ii}(cos(theta)<0) = 0;  % below ground plane
    G_vid_phi{ii} = zeros(size(theta));
    G_vid_tot = sqrt(abs(G_vid_theta{ii}).^2+abs(G_vid_phi{ii}).^2);
    G_vid_tot_dB = 20*log10(G_vid_tot);
    G_vid_tot_dB_scaled{ii} = max(G_vid_tot_dB+range_dB,0) / range_dB;  
end

% 3D radiation pattern:
figure;
sp = cell(numel(kh),1);
for ii = 1:numel(kh);
    sp{ii}=subplot(1,numel(kh),ii);
    plot_3d_farfield_sub(theta, phi, G_vid_tot_dB_scaled{ii})
    text = ['Vertical dipole:' char(10) 'h = ' num2str(h_lambda(ii)) '\lambda.'];
    annotation('textbox', [0.10+0.3*(ii-1),0.20,0.25,0.10], 'string', text, ...
    'HorizontalAlignment', 'center');
    caxis([0 1]);
end

if exist('savefigs', 'var') && savefigs
    save_fig('Fig5-12c.eps', 14, 10, 500, 1, 0, 0);
end