% Directivity and radiation resistance of a vertical dipole above a GP.
%
% Complement to Figure 5.13 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define height above ground plane (unit wavelength).
h_lambda = 0.01:0.01:5;

% Directivity from Eq. (5.58).
kh = 2*pi*h_lambda;
br = 1/3 - cos(2*kh)./(2*kh).^2 + sin(2*kh)./(2*kh).^3;
D0 = 2 * br.^-1;

% Radiation resistance from Eq. (5.59).
eta = 120*pi;
L_lambda = 1/50;
R_rad = 2*pi*eta * (0.5*L_lambda).^2 * br;

% Plot directivity and radiation resistance.
figure;
plot(h_lambda, 10*log10(D0), 'b-', h_lambda, 40*R_rad, 'r-');
legend('Directivity [dBi]', '40 \times radiation resistance [ohm]');
axis([0 5 0 10]);
grid on;
xlabel('Height [\lambda]');
