% Radiation pattern of a patch antenna (two-slot model).
%
% Complement to Figure 6.5 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define dimension patch.
l_eq_lambda = [0 0.25 0.375 0.5];

% Define angles.
theta_deg = -90:90;
[theta, kl_eq] = ndgrid(theta_deg*pi/180, 2*pi*l_eq_lambda);

% Calculate radiation pattern in E-plane using Eq. (6.7).
G_E = 0.5 * (1 + exp(1j*kl_eq.*sin(theta)));
G_E(cos(theta)<0) = 0;  % below ground plane

% Plot 2-D radiation patterns.
figure;
plot(theta_deg, 20*log10(abs(G_E)));
axis([-90 90 -40 10]);
grid on;
title('Patch antenna, E-plane');
xlabel('\theta [deg]');
ylabel('Relative level [dB]');
lgnds = cell(1, numel(l_eq_lambda));
for ii = 1:numel(lgnds)
    lgnds{ii} = sprintf('l_{eq} = %.3f \\lambda', l_eq_lambda(ii));
end
legend(lgnds, 'Location', 'southeast');
