% Radiation patterns of a patch antenna.
%
% Complement to Figure 6.5 in Foundations of Antennas by Per-Simon Kildal.

% By Madeleine Kildal Schilliger 2014-07-10

% Define theta and phi angles.
theta_deg = 0:0.5:180;
phi_deg = -180:0.5:180;
[theta, phi] = ndgrid(theta_deg*pi/180, phi_deg*pi/180);

% Far-field function from Eq. (6.7) and (6.8)
l_lambda = 0.375; 
I_m = 0.5;
kl = 2*pi*l_lambda;
ss = sin(theta) .* sin(phi);
G_pch_theta = - I_m * sin(phi) .* (1 + exp(1j*kl*ss));
G_pch_theta(cos(theta)<0) = 0;  % below ground plane
G_pch_phi = - I_m * cos(theta) .*  cos(phi) .* (1 + exp(1j*kl*ss));
G_pch_phi(cos(theta)<0) = 0;    % below ground plane

%% Contour radiation pattern
% Plot
plot_contour_farfield(theta, phi, G_pch_theta, G_pch_phi,'yprim')
if exist('savefigs', 'var') && savefigs
    save_fig('Fig6-05b.eps', 14, 10, 450, 1, 0, 0);
    save_fig('Fig6-05b.png', 14, 10, 1000, 1, 0, 1);
    colormap(flipud(pink(15)));
    save_fig('Fig6-05bgray.eps', 14, 10, 450, 1, 0, 0);
    save_fig('Fig6-05bgray.png', 14, 10, 1000, 1, 0, 1);
end

%% 3D radiation pattern
% Plot total 3D radiation pattern 
G_pch_tot = sqrt(abs(G_pch_theta).^2+abs(G_pch_phi).^2);
G_pch_tot_dB = 20*log10(G_pch_tot);
range_dB = 30;
G_pch_tot_dB_scaled = max(G_pch_tot_dB+range_dB,0) / range_dB;

figure;
zoomfactor = 0.5;
plot_3d_farfield_sub(theta, phi, G_pch_tot_dB_scaled)
zoom(zoomfactor)
if exist('savefigs', 'var') && savefigs
    save_fig('Fig6-05c.eps', 14, 10, 450, 1, 0, 0);
end