% E-plane sector horn, universal patterns.
%
% Complement to Figure 8.10 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define inputs.
x = 0:0.01:6;
Phi_max_deg = 0:90:360;

% Calculate.
Phi_max = Phi_max_deg*pi/180;
G_E = zeros(numel(x), numel(Phi_max));
u = linspace(-1, 1, 201);
du = u(2) - u(1);
lgnds = cell(1, numel(Phi_max));
for jj = 1:numel(Phi_max)
    for ii = 1:numel(x)
        Eint = exp(-1j*u.^2*Phi_max(jj)) .* exp(1j*pi*x(ii)*u);  % Eq. (8.12)
        G_E(ii,jj) = trapz(Eint)*du; 
    end
    G_E(:,jj) = G_E(:,jj) / G_E(1,jj);
    lgnds{jj} = sprintf('\\Phi_{max} = %0.f deg', Phi_max_deg(jj));
end

% Plot.
figure;
plot(x, 20*log10(abs(G_E)));
axis([min(x) max(x) -40 10]);
grid on;
legend(lgnds);
title('E-plane sector horn');
xlabel('(b/\lambda)sin(\theta)');
ylabel('Relative level [dB]');
