% H-plane sector horn, universal patterns.
%
% Complement to Figure 8.13 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define inputs.
x = 0:0.01:6;
Phi_max_deg = 0:90:360;

% Calculate.
Phi_max = Phi_max_deg*pi/180;
G_H = zeros(numel(x), numel(Phi_max));
u = linspace(-1, 1, 201);
du = u(2) - u(1);
lgnds = cell(1, numel(Phi_max));
for jj = 1:numel(Phi_max)
    for ii = 1:numel(x)
        Hint = cos(pi*u/2) .* exp(-1j*u.^2*Phi_max(jj)) .* exp(1j*pi*x(ii)*u);
            % Eq. (8.21)
        G_H(ii,jj) = trapz(Hint)*du; 
    end
    G_H(:,jj) = G_H(:,jj) / G_H(1,jj);
    lgnds{jj} = sprintf('\\Phi_{max} = %0.f deg', Phi_max_deg(jj));
end

% Plot.
figure;
plot(x, 20*log10(abs(G_H)));
axis([min(x) max(x) -40 10]);
grid on;
legend(lgnds);
title('H-plane sector horn');
xlabel('(a/\lambda)sin(\theta)');
ylabel('Relative level [dB]');
