% Universal radiation pattern of a corrugated (soft) conical horn.
%
% Complement to Figure 8.22 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input parameters.
Phi_max_deg = 0:90:360;
x = 0:0.01:6;  % 2*a/lambda*sin(theta)

% Calculate Eq. (8.56) and Eq. (8.57).
kappa01 = 2.405;  % besselj(0,x)==0 at x=kappa01
u = linspace(0, 1, 401);
[xx, uu] = ndgrid(x, u);
lgnds = cell(numel(Phi_max_deg), 1);
Eco45 = zeros(numel(x), numel(Phi_max_deg));
for ii = 1:numel(Phi_max_deg)
    Phi_max = Phi_max_deg(ii) * pi / 180;
    tmp0 = besselj(0, kappa01*u) .* exp(-1j*Phi_max*u.^2) .* u;
    Eco45(:,ii) = trapz(bsxfun(@times, tmp0, besselj(0,pi*xx.*uu)), 2);
    Eco45(:,ii) = Eco45(:,ii) / Eco45(1,ii);
    lgnds{ii,1} = sprintf('\\Phi_{max} = %.0f deg', Phi_max_deg(ii));
end
Gco45_dB = 20*log10(abs(Eco45));

% Plot.
figure;
plot(x, Gco45_dB, '-' ); hold on;
axis([min(x) max(x) -40 0]);
grid on;
title('Corrugated (soft) conical horn');
xlabel('(2a/\lambda)sin(\theta)');
ylabel('Relative level [dB]');
legend(lgnds(:));
