% Feed and spillover efficiency of a Cassegrain antenna.
%
% Complement to Figure 9.10 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
A0_dB = 5:0.05:30;            % feed illumination taper
theta_0_deg = [10 30 60 90];  % subtended half angle

% Calculate with Eq. (9.69) and Eq. (9.70).
[AA0_dB, theta_0] = ndgrid(A0_dB, theta_0_deg*pi/180);
n = AA0_dB ./ (-20*log10(cos(theta_0/2)));
ef = 4 * cot(theta_0/2).^2 .* (1-cos(theta_0/2).^n).^2 .* (n+1) ./ n.^2;
esp = 1 - cos(theta_0/2) .^ (2*n+2);

% Plot.
figure;
plot(A0_dB, 10*log10(ef));
axis([min(A0_dB) max(A0_dB) -3 -0.5]);
grid on;
title('Cassegrain antenna');
xlabel('Feed illumination taper [dB]');
ylabel('Feed efficiency [dB]');
lgnds = cell(numel(theta_0_deg), 1);
for ii = 1:numel(theta_0_deg)
    lgnds{ii} = sprintf('\\theta_0 = %.0f deg', theta_0_deg(ii));
end
legend(lgnds);

figure;
plot(A0_dB, 10*log10(esp));
axis([min(A0_dB) max(A0_dB) -1 0]);
grid on;
title('Cassegrain antenna');
xlabel('Feed illumination taper [dB]');
ylabel('Spillover efficiency [dB]');
legend(lgnds, 'Location', 'southeast');
