% Blockage efficiency of a Cassegrain antenna.
%
% Complement to Figure 9.14 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
doD = (0:0.001:0.5)';  % relative blockage diamater d/D
Apt_dB = [0 10 20];    % aperture illumination taper
theta_0_deg = 10;      % subtended half angle (not critical)

% Calculate with Eq. (9.106) and Eq. (9.104).
theta_0 = theta_0_deg*pi/180;
n = Apt_dB / (-20*log10(cos(theta_0/2)));
C_b = 0.5 * tan(theta_0/2)^2 * n ./ (1-cos(theta_0/2).^n);
C_b(n==0) = 0.5 * tan(theta_0/2)^2 ./ -log(cos(theta_0/2));  % Taylor exp.
Delta_cb = bsxfun(@times, C_b, doD.^2);
e_apb = (1-Delta_cb).^2;

% Plot.
figure;
plot(doD, 10*log10(e_apb));
axis([min(doD) max(doD) -3 0]);
grid on;
title('Cassegrain antenna');
xlabel('Relative blockage diameter d/D [-]');
ylabel('Blockage efficiency [dB]');
lgnds = cell(numel(Apt_dB), 1);
for ii = 1:numel(Apt_dB)
    lgnds{ii} = sprintf('Taper %.0f dB', Apt_dB(ii));
end
legend(lgnds(:));
